==> jc-1.4.0.tar.gz: gnu/xml/transform/Key.c <==
// class gnu.xml.transform.Key

// class file dependencies
// @dep_class a8e21f5a8a9bccaa gnu_xml_transform_Key
// @dep_class 83e341b0773e8a08 gnu_xml_transform_Stylesheet
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 206277a2844e515a javax_xml_namespace_QName

// header file dependencies
// @dep_header gnu_xml_transform_Key
// @dep_header gnu_xml_transform_Stylesheet
// @dep_header gnu_xml_xpath_Pattern
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_xml_namespace_QName

#include "jc_defs.h"

#include "gnu/xml/transform/Key.h"
#include "gnu/xml/transform/Stylesheet.h"
#include "gnu/xml/xpath/Pattern.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/xml/namespace/QName.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final javax.xml.namespace.QName name
static _jc_field _jc_gnu_xml_transform_Key$field_info$name = {
	.name=		"name",
	.signature=	"Ljavax/xml/namespace/QName;",
	.class=		&_jc_gnu_xml_transform_Key$type,
	.type=		&_jc_javax_xml_namespace_QName$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_Key$object, refs[-1].gnu_xml_transform_Key.name),
};

// final gnu.xml.xpath.Pattern match
static _jc_field _jc_gnu_xml_transform_Key$field_info$match = {
	.name=		"match",
	.signature=	"Lgnu/xml/xpath/Pattern;",
	.class=		&_jc_gnu_xml_transform_Key$type,
	.type=		&_jc_gnu_xml_xpath_Pattern$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_Key$object, refs[-1].gnu_xml_transform_Key.match),
};

// final gnu.xml.xpath.Expr use
static _jc_field _jc_gnu_xml_transform_Key$field_info$use = {
	.name=		"use",
	.signature=	"Lgnu/xml/xpath/Expr;",
	.class=		&_jc_gnu_xml_transform_Key$type,
	.type=		&_jc_gnu_xml_xpath_Expr$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_Key$object, refs[-1].gnu_xml_transform_Key.use),
};

// Fields
static _jc_field *const _jc_gnu_xml_transform_Key$fields[] = {
	&_jc_gnu_xml_transform_Key$field_info$match,
	&_jc_gnu_xml_transform_Key$field_info$name,
	&_jc_gnu_xml_transform_Key$field_info$use
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(javax.xml.namespace.QName, gnu.xml.xpath.Pattern, gnu.xml.xpath.Expr)
//

static _jc_linenum _jc_gnu_xml_transform_Key$linenum_table$_init$08cf062a5167e0de[];

static const unsigned char _jc_gnu_xml_transform_Key$param_ptypes$_init$08cf062a5167e0de[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_xml_transform_Key$param_types$_init$08cf062a5167e0de[] = {
	&_jc_javax_xml_namespace_QName$type,
	&_jc_gnu_xml_xpath_Pattern$type,
	&_jc_gnu_xml_xpath_Expr$type
};

_jc_method _jc_gnu_xml_transform_Key$method_info$_init$08cf062a5167e0de = {
	.name=			"<init>",
	.signature=		"(Ljavax/xml/namespace/QName;Lgnu/xml/xpath/Pattern;Lgnu/xml/xpath/Expr;)V",
	.class=			&_jc_gnu_xml_transform_Key$type,
	.param_types=		&_jc_gnu_xml_transform_Key$param_types$_init$08cf062a5167e0de,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_transform_Key$param_ptypes$_init$08cf062a5167e0de,
	.signature_hash=	_JC_JLONG(0x8cf062a5167e0de),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_transform_Key$method$_init$08cf062a5167e0de,
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_gnu_xml_transform_Key$linenum_table$_init$08cf062a5167e0de
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_Key, _init$08cf062a5167e0de);

void
_jc_gnu_xml_transform_Key$method$_init$08cf062a5167e0de(_jc_env *const env, _jc_gnu_xml_transform_Key$object *this, _jc_javax_xml_namespace_QName$object *param0, _jc_gnu_xml_xpath_Pattern$object *param1, _jc_gnu_xml_xpath_Expr$object *param2)
{
	struct _jc_gnu_xml_transform_Key$object *r0;
	struct _jc_javax_xml_namespace_QName$object *r1;
	struct _jc_gnu_xml_xpath_Pattern$object *r2;
	struct _jc_gnu_xml_xpath_Expr$object *r3;

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(58);				// 0
	_JC_REF_FIELD(env, r0, gnu_xml_transform_Key, name) = r1;
	_JC_LINE_NUMBER(59);				// 1
	_JC_REF_FIELD(env, r0, gnu_xml_transform_Key, match) = r2;
	_JC_LINE_NUMBER(60);				// 2
	_JC_REF_FIELD(env, r0, gnu_xml_transform_Key, use) = r3;
	_JC_LINE_NUMBER(61);				// 3
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// gnu.xml.transform.Key clone(gnu.xml.transform.Stylesheet)
//

static _jc_linenum _jc_gnu_xml_transform_Key$linenum_table$clone$3716537eef3cb25b[];

static const unsigned char _jc_gnu_xml_transform_Key$param_ptypes$clone$3716537eef3cb25b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_transform_Key$param_types$clone$3716537eef3cb25b[] = {
	&_jc_gnu_xml_transform_Stylesheet$type
};

_jc_method _jc_gnu_xml_transform_Key$method_info$clone$3716537eef3cb25b = {
	.name=			"clone",
	.signature=		"(Lgnu/xml/transform/Stylesheet;)Lgnu/xml/transform/Key;",
	.class=			&_jc_gnu_xml_transform_Key$type,
	.param_types=		&_jc_gnu_xml_transform_Key$param_types$clone$3716537eef3cb25b,
	.return_type=		&_jc_gnu_xml_transform_Key$type,
	.param_ptypes=		&_jc_gnu_xml_transform_Key$param_ptypes$clone$3716537eef3cb25b,
	.signature_hash=	_JC_JLONG(0x3716537eef3cb25b),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_transform_Key$vtable, gnu_xml_transform_Key.clone$3716537eef3cb25b) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_transform_Key$linenum_table$clone$3716537eef3cb25b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_Key, clone$3716537eef3cb25b);

_jc_gnu_xml_transform_Key$object *
_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b(_jc_env *const env, _jc_gnu_xml_transform_Key$object *this, _jc_gnu_xml_transform_Stylesheet$object *param0)
{
	struct _jc_gnu_xml_transform_Key$object *r0;
	struct _jc_gnu_xml_transform_Stylesheet$object *r1;
	struct _jc_gnu_xml_transform_Key$object *r2;
	struct _jc_javax_xml_namespace_QName$object *r3;
	struct _jc_gnu_xml_xpath_Pattern$object *r4;
	struct _jc_gnu_xml_xpath_Expr$object *r5;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(65);				// 0
	r2 = _JC_NEW(env, gnu_xml_transform_Key);
	r3 = _JC_REF_FIELD(env, r0, gnu_xml_transform_Key, name);
	r4 = _JC_REF_FIELD(env, r0, gnu_xml_transform_Key, match);
	r5 = _JC_INVOKE_VIRTUAL(env, gnu_xml_xpath_Expr, clone$8aac957948447f2f, r4, r1);
	r4 = _JC_CAST(env, &_jc_gnu_xml_xpath_Pattern$type, r5);
	r5 = _JC_REF_FIELD(env, r0, gnu_xml_transform_Key, use);
	r5 = _JC_INVOKE_VIRTUAL(env, gnu_xml_xpath_Expr, clone$8aac957948447f2f, r5, r1);
	_JC_REF_FIELD(env, r2, gnu_xml_transform_Key, name) = r3;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_Key, match) = r4;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_Key, use) = r5;
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_transform_Key$methods[] = {
	&_jc_gnu_xml_transform_Key$method_info$_init$08cf062a5167e0de,
	&_jc_gnu_xml_transform_Key$method_info$clone$3716537eef3cb25b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_transform_Key$instanceof_hash_bucket_42[] = {
	&_jc_gnu_xml_transform_Key$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_transform_Key$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_transform_Key$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[42]=	_jc_gnu_xml_transform_Key$instanceof_hash_bucket_42,
	[113]=	_jc_gnu_xml_transform_Key$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_transform_Key$class_depends[] = {
	{ "gnu/xml/transform/Stylesheet",	_JC_JLONG(0x83e341b0773e8a08) },
	{ "gnu/xml/xpath/Expr",	_JC_JLONG(0xd90c61647700b7f6) },
	{ "gnu/xml/xpath/Pattern",	_JC_JLONG(0x4fc1b12fbb0cffd4) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/xml/namespace/QName",	_JC_JLONG(0x206277a2844e515a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_transform_Key$vtype _jc_gnu_xml_transform_Key$type = {
    .type= {
	.name=			"gnu/xml/transform/Key",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xa8e21f5a8a9bccaa),
		.source_file=		"Key.java",
		.instance_size=		sizeof(_jc_gnu_xml_transform_Key$refs) + sizeof(_jc_gnu_xml_transform_Key$object),
		.num_virtual_refs=	3,
		.num_fields=		sizeof(_jc_gnu_xml_transform_Key$fields) / sizeof(*_jc_gnu_xml_transform_Key$fields),
		.fields=		_jc_gnu_xml_transform_Key$fields,
		.num_methods=		sizeof(_jc_gnu_xml_transform_Key$methods) / sizeof(*_jc_gnu_xml_transform_Key$methods),
		.methods=		_jc_gnu_xml_transform_Key$methods,
		.instanceof_hash_table=	_jc_gnu_xml_transform_Key$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_transform_Key$class_depends) / sizeof(*_jc_gnu_xml_transform_Key$class_depends),
		.class_depends=		_jc_gnu_xml_transform_Key$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_transform_Key= {
	    .clone$3716537eef3cb25b=
		&_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/xml/transform/Key.c <==
// class gnu.xml.transform.Key

// class file dependencies
// @dep_class a8e21f5a8a9bccaa gnu_xml_transform_Key
// @dep_class 83e341b0773e8a08 gnu_xml_transform_Stylesheet
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 206277a2844e515a javax_xml_namespace_QName

// header file dependencies
// @dep_header gnu_xml_transform_Key
// @dep_header gnu_xml_transform_Stylesheet
// @dep_header gnu_xml_xpath_Pattern
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_xml_namespace_QName

#include "jc_defs.h"

#include "gnu/xml/transform/Key.h"
#include "gnu/xml/transform/Stylesheet.h"
#include "gnu/xml/xpath/Pattern.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/xml/namespace/QName.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final javax.xml.namespace.QName name
static _jc_field _jc_gnu_xml_transform_Key$field_info$name = {
	.name=		"name",
	.signature=	"Ljavax/xml/namespace/QName;",
	.class=		&_jc_gnu_xml_transform_Key$type,
	.type=		&_jc_javax_xml_namespace_QName$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_Key$object, refs[-1].gnu_xml_transform_Key.name),
};

// final gnu.xml.xpath.Pattern match
static _jc_field _jc_gnu_xml_transform_Key$field_info$match = {
	.name=		"match",
	.signature=	"Lgnu/xml/xpath/Pattern;",
	.class=		&_jc_gnu_xml_transform_Key$type,
	.type=		&_jc_gnu_xml_xpath_Pattern$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_Key$object, refs[-1].gnu_xml_transform_Key.match),
};

// final gnu.xml.xpath.Expr use
static _jc_field _jc_gnu_xml_transform_Key$field_info$use = {
	.name=		"use",
	.signature=	"Lgnu/xml/xpath/Expr;",
	.class=		&_jc_gnu_xml_transform_Key$type,
	.type=		&_jc_gnu_xml_xpath_Expr$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_transform_Key$object, refs[-1].gnu_xml_transform_Key.use),
};

// Fields
static _jc_field *const _jc_gnu_xml_transform_Key$fields[] = {
	&_jc_gnu_xml_transform_Key$field_info$match,
	&_jc_gnu_xml_transform_Key$field_info$name,
	&_jc_gnu_xml_transform_Key$field_info$use
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(javax.xml.namespace.QName, gnu.xml.xpath.Pattern, gnu.xml.xpath.Expr)
//

static _jc_linenum _jc_gnu_xml_transform_Key$linenum_table$_init$08cf062a5167e0de[];

static const unsigned char _jc_gnu_xml_transform_Key$param_ptypes$_init$08cf062a5167e0de[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_xml_transform_Key$param_types$_init$08cf062a5167e0de[] = {
	&_jc_javax_xml_namespace_QName$type,
	&_jc_gnu_xml_xpath_Pattern$type,
	&_jc_gnu_xml_xpath_Expr$type
};

_jc_method _jc_gnu_xml_transform_Key$method_info$_init$08cf062a5167e0de = {
	.name=			"<init>",
	.signature=		"(Ljavax/xml/namespace/QName;Lgnu/xml/xpath/Pattern;Lgnu/xml/xpath/Expr;)V",
	.class=			&_jc_gnu_xml_transform_Key$type,
	.param_types=		&_jc_gnu_xml_transform_Key$param_types$_init$08cf062a5167e0de,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_transform_Key$param_ptypes$_init$08cf062a5167e0de,
	.signature_hash=	_JC_JLONG(0x8cf062a5167e0de),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_transform_Key$method$_init$08cf062a5167e0de,
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_gnu_xml_transform_Key$linenum_table$_init$08cf062a5167e0de
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_Key, _init$08cf062a5167e0de);

void _JC_JCNI_ATTR
_jc_gnu_xml_transform_Key$method$_init$08cf062a5167e0de(_jc_env *const env, _jc_gnu_xml_transform_Key$object *this, _jc_javax_xml_namespace_QName$object *param0, _jc_gnu_xml_xpath_Pattern$object *param1, _jc_gnu_xml_xpath_Expr$object *param2)
{
	struct _jc_gnu_xml_transform_Key$object *r0;
	struct _jc_javax_xml_namespace_QName$object *r1;
	struct _jc_gnu_xml_xpath_Pattern$object *r2;
	struct _jc_gnu_xml_xpath_Expr$object *r3;

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(58);				// 0
	_JC_REF_FIELD(env, r0, gnu_xml_transform_Key, name) = r1;
	_JC_LINE_NUMBER(59);				// 1
	_JC_REF_FIELD(env, r0, gnu_xml_transform_Key, match) = r2;
	_JC_LINE_NUMBER(60);				// 2
	_JC_REF_FIELD(env, r0, gnu_xml_transform_Key, use) = r3;
	_JC_LINE_NUMBER(61);				// 3
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// gnu.xml.transform.Key clone(gnu.xml.transform.Stylesheet)
//

static _jc_linenum _jc_gnu_xml_transform_Key$linenum_table$clone$3716537eef3cb25b[];

static const unsigned char _jc_gnu_xml_transform_Key$param_ptypes$clone$3716537eef3cb25b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_transform_Key$param_types$clone$3716537eef3cb25b[] = {
	&_jc_gnu_xml_transform_Stylesheet$type
};

_jc_method _jc_gnu_xml_transform_Key$method_info$clone$3716537eef3cb25b = {
	.name=			"clone",
	.signature=		"(Lgnu/xml/transform/Stylesheet;)Lgnu/xml/transform/Key;",
	.class=			&_jc_gnu_xml_transform_Key$type,
	.param_types=		&_jc_gnu_xml_transform_Key$param_types$clone$3716537eef3cb25b,
	.return_type=		&_jc_gnu_xml_transform_Key$type,
	.param_ptypes=		&_jc_gnu_xml_transform_Key$param_ptypes$clone$3716537eef3cb25b,
	.signature_hash=	_JC_JLONG(0x3716537eef3cb25b),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_transform_Key$vtable, gnu_xml_transform_Key.clone$3716537eef3cb25b) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_transform_Key$linenum_table$clone$3716537eef3cb25b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_transform_Key, clone$3716537eef3cb25b);

_jc_gnu_xml_transform_Key$object * _JC_JCNI_ATTR
_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b(_jc_env *const env, _jc_gnu_xml_transform_Key$object *this, _jc_gnu_xml_transform_Stylesheet$object *param0)
{
	struct _jc_gnu_xml_transform_Key$object *r0;
	struct _jc_gnu_xml_transform_Stylesheet$object *r1;
	struct _jc_gnu_xml_transform_Key$object *r2;
	struct _jc_javax_xml_namespace_QName$object *r3;
	struct _jc_gnu_xml_xpath_Pattern$object *r4;
	struct _jc_gnu_xml_xpath_Expr$object *r5;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(65);				// 0
	r2 = _JC_NEW(env, gnu_xml_transform_Key);
	r3 = _JC_REF_FIELD(env, r0, gnu_xml_transform_Key, name);
	r4 = _JC_REF_FIELD(env, r0, gnu_xml_transform_Key, match);
	r5 = _JC_INVOKE_VIRTUAL(env, gnu_xml_xpath_Expr, clone$8aac957948447f2f, r4, r1);
	r4 = _JC_CAST(env, &_jc_gnu_xml_xpath_Pattern$type, r5);
	r5 = _JC_REF_FIELD(env, r0, gnu_xml_transform_Key, use);
	r5 = _JC_INVOKE_VIRTUAL(env, gnu_xml_xpath_Expr, clone$8aac957948447f2f, r5, r1);
	_JC_REF_FIELD(env, r2, gnu_xml_transform_Key, name) = r3;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_Key, match) = r4;
	_JC_REF_FIELD(env, r2, gnu_xml_transform_Key, use) = r5;
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_transform_Key$methods[] = {
	&_jc_gnu_xml_transform_Key$method_info$_init$08cf062a5167e0de,
	&_jc_gnu_xml_transform_Key$method_info$clone$3716537eef3cb25b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_transform_Key$instanceof_hash_bucket_42[] = {
	&_jc_gnu_xml_transform_Key$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_transform_Key$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_transform_Key$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[42]=	_jc_gnu_xml_transform_Key$instanceof_hash_bucket_42,
	[101]=	_jc_gnu_xml_transform_Key$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_transform_Key$class_depends[] = {
	{ "gnu/xml/transform/Stylesheet",	_JC_JLONG(0x83e341b0773e8a08) },
	{ "gnu/xml/xpath/Expr",	_JC_JLONG(0xd90c61647700b7f6) },
	{ "gnu/xml/xpath/Pattern",	_JC_JLONG(0x4fc1b12fbb0cffd4) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/xml/namespace/QName",	_JC_JLONG(0x206277a2844e515a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_transform_Key$vtype _jc_gnu_xml_transform_Key$type = {
    .type= {
	.name=			"gnu/xml/transform/Key",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xa8e21f5a8a9bccaa),
		.source_file=		"Key.java",
		.instance_size=		sizeof(_jc_gnu_xml_transform_Key$refs) + sizeof(_jc_gnu_xml_transform_Key$object),
		.num_virtual_refs=	3,
		.num_fields=		sizeof(_jc_gnu_xml_transform_Key$fields) / sizeof(*_jc_gnu_xml_transform_Key$fields),
		.fields=		_jc_gnu_xml_transform_Key$fields,
		.num_methods=		sizeof(_jc_gnu_xml_transform_Key$methods) / sizeof(*_jc_gnu_xml_transform_Key$methods),
		.methods=		_jc_gnu_xml_transform_Key$methods,
		.instanceof_hash_table=	_jc_gnu_xml_transform_Key$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_transform_Key$class_depends) / sizeof(*_jc_gnu_xml_transform_Key$class_depends),
		.class_depends=		_jc_gnu_xml_transform_Key$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_transform_Key= {
	    .clone$3716537eef3cb25b=
		&_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b,
	},
    }
};
